!     This subroutine calculates force at each step and writes it to the file
!     force.out      
              
      subroutine calc_out_force
      implicit doubleprecision (a-h,o-z)       
      include 'arrays2.cm'
      
!     calculate Force
      
      Force_G_plus_V_max_Abs=0.0d0
      Force_tip_max_Abs_1=0.0d0
      i_step_max = 0

!     Calculate force as a derivative olf the free energy G+V, where G+V in Jmol-1
       
      do i_step=2,n_out-1
        write(*,*)i_step, 'rtip',r_tip(i_step)           
        Force_G_plus_V_avrg(i_step)=
     &   (G_plus_V_avrg(i_step+1)-G_plus_V_avrg(i_step))
     &   /(r_tip(i_step+1)-r_tip(i_step))
       
        if (dabs(Force_G_plus_V_avrg(i_step)) 
     &  .gt.Force_G_plus_V_max_Abs)then
          Force_G_plus_V_max_Abs = dabs(Force_G_plus_V_avrg(i_step))
          Force_G_plus_V_max     =      Force_G_plus_V_avrg(i_step)
          i_step_max=i_step
        end if
       
!     Calculate average extension, A
     
         r_protein_avrg=0.0d0
         p_norm_local=0.0d0
         do i_box=1,nbox
           p_norm_local=p_norm_local+p_step(i_box,i_step)
         end do    
           
         do i_box=1,nbox
           r_protein_avrg=r_protein_avrg
     &     +(p_step(i_box,i_step)/p_norm_local)*box_center_tot(i_box)      
         end do    
       
         r_avrg(i_step)=r_protein_avrg-r0
         delta_r=r_avrg(i_step)-r_tip(i_step)  ! r_protein_avrg-r0-r_tip(i_step)
       
         call calculate_tip_force(delta_r, f_tip)

         Force_tip(i_step)=f_tip
       
         if (dabs(Force_tip(i_step)).gt.Force_tip_max_Abs_1) then
           Force_tip_max_Abs_1 = dabs(Force_tip(i_step))
           Force_tip_max_1     =      Force_tip(i_step)
           i_step_max_tip=i_step
         end if      
       
       end do
 
 !    output force

      do i_step=2,n_out-1
        write (800,1) 
     &  i_step, r_tip(i_step),   
     &  Force_G_plus_V_avrg(i_step)*1.0d10*1.0d12/6.0d23,  !Force_G_plus_V_avrg in J mol-1 A-1, /NA removes mol-1, A-1 > m-1 *d10 = J/m=N, *1d12 =pN
     &  r_avrg(i_step), -Force_tip(i_step)                 !Force tip already in pN, no need to convert
1       format (1x,i6, 4(2x,e19.12))      
      end do    
      write (800,*) ' '
      write (800,2) i_step_max, r_tip(i_step_max), 
     &  Force_G_plus_V_max_Abs *1.0d10*1.0d12/6.0d23,      ! Same unit conversions as above
     &  i_step_max_tip, 
     &  r_tip(i_step_max_tip),  r_avrg(i_step_max_tip), 
     &  Force_tip_max_Abs_1
 2    format(2x,i6,2(2x,e19.12),2x,i6,3(2x,e19.12))      
      return
      end     
       



!    This subroutine writes probabilities and free energies it to the files
!    p_tot.out and free_energy.out
	      
      subroutine output_p_and_G
      implicit doubleprecision (a-h,o-z)
      include 'arrays2.cm'

!     We output zeros at the beginning and at the end of the output for the future ease of plotting things in origin. 
	
      ibox=0
      p_ibox       =0.0d0
      G_ibox       =0.0d0
      G_plus_V_ibox=0.0d0
      box_center_tot_ibox=box_center_tot(1)-1.0d0
      write (798, 1) ibox, box_center_tot_ibox, p_ibox
      write (797, 2) ibox, box_center_tot_ibox, G_ibox, G_plus_V_ibox
                                                                          !
      do ibox=1,nbox_tot                                                  !   Having nbox_tot here is important   
      write (798, 1) ibox, box_center_tot(ibox), p_tot(ibox)              !   Must be p_tot(ibox) not p(ibox) 
  1   format (1x, i4, 4x, 2(e17.10,2x))
      write (797, 2) ibox, box_center_tot(ibox), G(ibox), G_plus_V(ibox)
  2   format (1x, i4, 4x, 3(e17.10,2x))    
      end do    

      ibox=nbox+1
      p_ibox       =0.0d0
      G_ibox       =0.0d0
      G_plus_V_ibox=0.0d0
      box_center_tot_ibox=box_center_tot(nbox)+1.0d0
      write (798, 1) ibox, box_center_tot_ibox, p_ibox
      write (797, 2) ibox, box_center_tot_ibox, G_ibox, G_plus_V_ibox
           
      return
      end     





!     Knowing "average extension" this subroutine calculate the elastic force.
   
      subroutine calculate_tip_force(delta_r, f_tip)	
      implicit doubleprecision (a-h,o-z)
      include 'arrays2.cm'
      
      call calculate_tip_force_harm(delta_r, f_tip)
!     call calculate_tip_force_exp(delta_r, f_tip)      
      
      return
      end




!     Knowing "average extension" this subroutine calculate the elastic force for harmonic tip.
     
      subroutine calculate_tip_force_harm(delta_r, f_tip)	 
      implicit doubleprecision (a-h,o-z)
      include 'arrays2.cm'
      
      if (delta_r.le.0.0d0) then 
          f_tip=force_constant*delta_r
      else
          f_tip=0.0d0
      end if    
      
      return
      end

